@@ -3,8 +3,8 @@
 /**
  * @file classes/services/PKPSubmissionService.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SubmissionService
@@ -15,6 +15,8 @@
 
 namespace PKP\Services;
 
+use function PHP81_BC\strftime;
+
 use \Core;
 use \DBResultRange;
 use \Application;
@@ -101,7 +103,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 		$submissionListQO = $this->getQueryBuilder($args)->getQuery();
 		$submissionDao = DAORegistry::getDAO('SubmissionDAO'); /* @var $submissionDao SubmissionDAO */
 		$result = $submissionDao->retrieveRange($submissionListQO->toSql(), $submissionListQO->getBindings(), $range);
-		$queryResults = new DAOResultFactory($result, $submissionDao, '_fromRow');
+		$queryResults = new DAOResultFactory($result, $submissionDao, '_fromRow', [], $submissionListQO, [], $range);
 
 		return $queryResults->toIterator();
 	}
@@ -126,7 +128,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 			'contextId' => CONTEXT_ID_NONE,
 			'orderBy' => 'dateSubmitted',
 			'orderDirection' => 'DESC',
-			'assignedTo' => null,
+			'assignedTo' => [],
 			'status' => null,
 			'stageIds' => null,
 			'searchPhrase' => null,
@@ -158,7 +160,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 			$submissionListQB->offsetBy($args['count']);
 		}
 
-		\HookRegistry::call('Submission::getMany::queryBuilder', array($submissionListQB, $args));
+		\HookRegistry::call('Submission::getMany::queryBuilder', array(&$submissionListQB, $args));
 
 		return $submissionListQB;
 	}
@@ -277,7 +279,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 	}
 
 	/**
-	 * Returns properties for the backend UI SubmissionListPanel component
+	 * Returns properties for custom API endpoints used in the backend
 	 * @param Submission $submission
 	 * @param array extra arguments
 	 *		$args['request'] PKPRequest Required
@@ -309,14 +311,14 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 
 		$reviews = array();
 		foreach($reviewAssignments as $reviewAssignment) {
-			// @todo for now, only show reviews that haven't been
-			// declined or cancelled
-			if ($reviewAssignment->getDeclined()) {
+			if ($reviewAssignment->getDeclined() || $reviewAssignment->getCancelled()) {
 				continue;
 			}
 
-			$currentUser = \Application::get()->getRequest()->getUser();
-			$dateFormatShort = \Config::getVar('general', 'date_format_short');
+			$request = \Application::get()->getRequest();
+			$currentUser = $request->getUser();
+			$context = $request->getContext();
+			$dateFormatShort = $context->getLocalizedDateFormatShort();
 			$due = is_null($reviewAssignment->getDateDue()) ? null : strftime($dateFormatShort, strtotime($reviewAssignment->getDateDue()));
 			$responseDue = is_null($reviewAssignment->getDateResponseDue()) ? null : strftime($dateFormatShort, strtotime($reviewAssignment->getDateResponseDue()));
 
@@ -471,12 +473,13 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 						$stage['status'] = __($reviewRound->getStatusKey());
 
 						// Revision files in this round.
-						import('lib.pkp.classes.submission.SubmissionFile');
-						$submissionFileDao = DAORegistry::getDAO('SubmissionFileDAO'); /* @var $submissionFileDao SubmissionFileDAO */
-						$submissionFiles = $submissionFileDao->getRevisionsByReviewRound($reviewRound, SUBMISSION_FILE_REVIEW_REVISION);
-						$stage['files'] = array(
-							'count' => count($submissionFiles),
-						);
+						$stage['files'] = [
+							'count' => Services::get('submissionFile')->getCount([
+								'submissionIds' => [$submission->getId()],
+								'fileStages' => [SUBMISSION_FILE_REVIEW_REVISION],
+								'reviewRounds' => [$reviewRound->getId()],
+							]),
+						];
 
 						// See if the  curent user can only recommend:
 						$stageAssignmentDao = DAORegistry::getDAO('StageAssignmentDAO'); /* @var $stageAssignmentDao StageAssignmentDAO */
@@ -493,9 +496,9 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 						}
 					} else {
 						// workaround for pkp/pkp-lib#4231, pending formal data model
-						$stage['files'] = array(
+						$stage['files'] = [
 							 'count' => 0
-						);
+						];
 					}
 					break;
 
@@ -504,12 +507,12 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 				case WORKFLOW_STAGE_ID_EDITING:
 				case WORKFLOW_STAGE_ID_PRODUCTION:
 					import('lib.pkp.classes.submission.SubmissionFile'); // Import constants
-					$submissionFileDao = DAORegistry::getDAO('SubmissionFileDAO'); /* @var $submissionFileDao SubmissionFileDAO */
-					$fileStageIId = $stageId === WORKFLOW_STAGE_ID_EDITING ? SUBMISSION_FILE_COPYEDIT : SUBMISSION_FILE_PROOF;
-					$submissionFiles = $submissionFileDao->getLatestRevisions($submission->getId(), $fileStageIId);
-					$stage['files'] = array(
-						'count' => count($submissionFiles),
-					);
+					$stage['files'] = [
+						'count' => Services::get('submissionFile')->getCount([
+							'submissionIds' => [$submission->getId()],
+							'fileStages' => [WORKFLOW_STAGE_ID_EDITING ? SUBMISSION_FILE_COPYEDIT : SUBMISSION_FILE_PROOF],
+						]),
+					];
 					break;
 			}
 
@@ -600,7 +603,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 		// Send reviewers to review wizard
 		$reviewAssignmentDao = DAORegistry::getDAO('ReviewAssignmentDAO'); /* @var $reviewAssignmentDao ReviewAssignmentDAO */
 		$reviewAssignment = $reviewAssignmentDao->getLastReviewRoundReviewAssignmentByReviewer($submission->getId(), $user->getId());
-		if ($reviewAssignment) {
+		if ($reviewAssignment && !$reviewAssignment->getCancelled() && !$reviewAssignment->getDeclined()) {
 			return $dispatcher->url(
 				$request,
 				ROUTE_PAGE,
@@ -655,7 +658,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 		} else {
 			if ($submission->getSubmissionProgress() != 0 ) {
 				$stageAssignmentDao = DAORegistry::getDAO('StageAssignmentDAO'); /* @var $stageAssignmentDao StageAssignmentDAO */
-				$assignments = $stageAssignmentDao->getBySubmissionAndRoleId($submission->getId(), ROLE_ID_AUTHOR, 1, $currentUser->getId());
+				$assignments = $stageAssignmentDao->getBySubmissionAndRoleId($submission->getId(), ROLE_ID_AUTHOR, WORKFLOW_STAGE_ID_SUBMISSION, $currentUser->getId());
 				$assignment = $assignments->next();
 				if ($assignment) {
 					$canDelete = true;
@@ -716,8 +719,8 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 
 		// The contextId must match an existing context
 		$validator->after(function($validator) use ($props) {
-			if (isset($props['contextid']) && !$validator->errors()->get('contextid')) {
-				$submissionContext = Services::get('context')->get($props['contextid']);
+			if (isset($props['contextId']) && !$validator->errors()->get('contextId')) {
+				$submissionContext = Services::get('context')->get($props['contextId']);
 				if (!$submissionContext) {
 					$validator->errors()->add('contextId', __('submission.submit.noContext'));
 				}
@@ -746,7 +749,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 		$submissionId = $submissionDao->insertObject($submission);
 		$submission = $this->get($submissionId);
 
-		\HookRegistry::call('Submission::add', [$submission, $request]);
+		\HookRegistry::call('Submission::add', [&$submission, $request]);
 
 		return $submission;
 	}
@@ -762,7 +765,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 		$submission->stampLastActivity();
 		$submission->stampModified();
 
-		\HookRegistry::call('Submission::edit', [$newSubmission, $submission, $params, $request]);
+		\HookRegistry::call('Submission::edit', [&$newSubmission, $submission, $params, $request]);
 
 		$submissionDao->updateObject($newSubmission);
 		$newSubmission = $this->get($newSubmission->getId());
@@ -774,12 +777,12 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 	 * @copydoc \PKP\Services\EntityProperties\EntityWriteInterface::delete()
 	 */
 	public function delete($submission) {
-		\HookRegistry::call('Submission::delete::before', [$submission]);
+		\HookRegistry::call('Submission::delete::before', [&$submission]);
 
 		$submissionDao = DAORegistry::getDAO('SubmissionDAO'); /* @var $submissionDao SubmissionDAO */
 		$submissionDao->deleteObject($submission);
 
-		\HookRegistry::call('Submission::delete', [$submission]);
+		\HookRegistry::call('Submission::delete', [&$submission]);
 	}
 
 	/**
@@ -791,16 +794,16 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 	 */
 	public function canEditPublication($submissionId, $userId) {
 		$stageAssignmentDao = DAORegistry::getDAO('StageAssignmentDAO'); /* @var $stageAssignmentDao StageAssignmentDAO */
-		$stageAssignments = $stageAssignmentDao->getBySubmissionAndUserIdAndStageId($submissionId, $userId, null);
+		$stageAssignments = $stageAssignmentDao->getBySubmissionAndUserIdAndStageId($submissionId, $userId, null)->toArray();
 		// Check for permission from stage assignments
-		while ($stageAssignment = $stageAssignments->next()) {
+		foreach ($stageAssignments as $stageAssignment) {
 			if ($stageAssignment->getCanChangeMetadata()) {
 				return true;
 			}
 		}
 		// If user has no stage assigments, check if user can edit anyway ie. is manager
 		$context = Application::get()->getRequest()->getContext();
-		if ($stageAssignments->wasEmpty() && $this->_canUserAccessUnassignedSubmissions($context->getId(), $userId)){
+		if (count($stageAssignments) == 0 && $this->_canUserAccessUnassignedSubmissions($context->getId(), $userId)) {
 			return true;
 		}
 		// Else deny access
@@ -842,7 +845,7 @@ abstract class PKPSubmissionService implements EntityPropertyInterface, EntityRe
 		// There should always be at least one publication for a submission. If
 		// not, an error has occurred in the code and will cause problems.
 		if (empty($publications)) {
-			throw new Exception('Tried to update the status of submission ' . $submission->getId() . ' and no publications were found.');
+			throw new \Exception('Tried to update the status of submission ' . $submission->getId() . ' and no publications were found.');
 		}
 
 		// Get the new current publication after status changes or deletions
