@@ -3,8 +3,8 @@
 /**
  * @file pages/submission/SubmissionHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SubmissionHandler
@@ -24,26 +24,7 @@ class SubmissionHandler extends PKPSubmissionHandler {
 	function __construct() {
 		parent::__construct();
 		$this->addRoleAssignment(array(ROLE_ID_AUTHOR, ROLE_ID_SUB_EDITOR, ROLE_ID_MANAGER),
-				array('index', 'wizard', 'step', 'saveStep', 'fetchChoices'));
-	}
-
-
-	//
-	// Public Handler Methods
-	//
-	/**
-	 * Retrieves a JSON list of available choices for a tagit metadata input field.
-	 * @param $args array
-	 * @param $request Request
-	 */
-	function fetchChoices($args, $request) {
-		$codeList = (int) $request->getUserVar('codeList');
-		$term = $request->getUserVar('term');
-
-		$onixCodelistItemDao = DAORegistry::getDAO('ONIXCodelistItemDAO'); /* @var $onixCodelistItemDao ONIXCodelistItemDAO */
-		$codes = $onixCodelistItemDao->getCodes('List' . $codeList, array(), $term); // $term is escaped in the getCodes method.
-		header('Content-Type: text/json');
-		echo json_encode(array_values($codes));
+				array('index', 'wizard', 'step', 'saveStep'));
 	}
 
 
