@@ -201,7 +201,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		$descDetailNode = $doc->createElementNS($deployment->getNamespace(), 'DescriptiveDetail');
 
 		$descDetailNode->appendChild($this->_buildTextNode($doc, 'ProductComposition',
-				$publicationFormat->getProductCompositionCode() ? $publicationFormat->getProductCompositionCode() : '00')); // single item, trade only, etc.  Default to single item if not specified.
+			$publicationFormat->getProductCompositionCode() ? $publicationFormat->getProductCompositionCode() : '00')); // single item, trade only, etc.  Default to single item if not specified.
 
 		$descDetailNode->appendChild($this->_buildTextNode($doc, 'ProductForm', $publicationFormat->getEntryKey()));  // paperback, hardcover, etc
 
@@ -237,7 +237,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			}
 		}
 
-		if($publicationFormat->getCountryManufactureCode() != '') {
+		if ($publicationFormat->getCountryManufactureCode() != '') {
 			$descDetailNode->appendChild($this->_buildTextNode($doc, 'CountryOfManufacture', $publicationFormat->getCountryManufactureCode()));
 		}
 
@@ -247,24 +247,23 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 		/* --- Collection information, first for series and then for product --- */
 
-		$seriesCollectionNode = $doc->createElementNS($deployment->getNamespace(), 'Collection');
-		$seriesCollectionNode->appendChild($this->_buildTextNode($doc, 'CollectionType', '10')); // publisher series.
-		$descDetailNode->appendChild($seriesCollectionNode);
-
-		$seriesTitleDetailNode = $doc->createElementNS($deployment->getNamespace(), 'TitleDetail');
-		$seriesTitleDetailNode->appendChild($this->_buildTextNode($doc, 'TitleType', '01'));
-		$seriesCollectionNode->appendChild($seriesTitleDetailNode);
-
-		$titleElementNode = $doc->createElementNS($deployment->getNamespace(), 'TitleElement');
-		$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleElementLevel', '02')); // Collection level title
-		$seriesTitleDetailNode->appendChild($titleElementNode);
-
 		/* --- Series information, if this monograph is part of one. --- */
 
 		$seriesDao = DAORegistry::getDAO('SeriesDAO'); /* @var $seriesDao SeriesDAO */
 		$series = $seriesDao->getById($submission->getCurrentPublication()->getData('seriesId'));
 		if ($series != null) {
 
+			$seriesCollectionNode = $doc->createElementNS($deployment->getNamespace(), 'Collection');
+			$seriesCollectionNode->appendChild($this->_buildTextNode($doc, 'CollectionType', '10')); // publisher series.
+
+			$seriesTitleDetailNode = $doc->createElementNS($deployment->getNamespace(), 'TitleDetail');
+			$seriesTitleDetailNode->appendChild($this->_buildTextNode($doc, 'TitleType', '01'));
+			$seriesCollectionNode->appendChild($seriesTitleDetailNode);
+
+			$titleElementNode = $doc->createElementNS($deployment->getNamespace(), 'TitleElement');
+			$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleElementLevel', '02')); // Collection level title
+			$seriesTitleDetailNode->appendChild($titleElementNode);
+
 			if ($submission->getCurrentPublication()->getData('seriesPosition')) {
 				$titleElementNode->appendChild($this->_buildTextNode($doc, 'PartNumber', $submission->getCurrentPublication()->getData('seriesPosition')));
 			}
@@ -274,15 +273,20 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			} else {
 				if ($series->getLocalizedPrefix() != '') {
 					$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitlePrefix', $series->getLocalizedPrefix()));
+				} else {
+					$titleElementNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoPrefix'));
 				}
-
 				$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleWithoutPrefix', $series->getLocalizedTitle(false)));
 			}
 
 			if ($series->getLocalizedSubtitle() != '') {
 				$titleElementNode->appendChild($this->_buildTextNode($doc, 'Subtitle', $series->getLocalizedSubtitle()));
 			}
+		} else {
+			$seriesCollectionNode = $doc->createElementNS($deployment->getNamespace(), 'NoCollection');
 		}
+		$descDetailNode->appendChild($seriesCollectionNode);
+
 
 		/* --- and now product level info --- */
 
@@ -301,7 +305,10 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		} else {
 			if ($publication->getLocalizedData('prefix')) {
 				$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitlePrefix', $publication->getLocalizedData('prefix')));
+			} else {
+				$titleElementNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoPrefix'));
 			}
+
 			$titleElementNode->appendChild($this->_buildTextNode($doc, 'TitleWithoutPrefix', $publication->getLocalizedTitle()));
 		}
 
@@ -320,9 +327,10 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$userGroupDao = DAORegistry::getDAO('UserGroupDAO'); /* @var $userGroupDao UserGroupDAO */
 			$userGroup = $userGroupDao->getById($author->getUserGroupId(), $submission->getContextId());
 
-			$userGroupOnixMap = array('AU' => 'A01', 'VE' => 'B01', 'CA' => 'A01', 'Trans' => 'B06', 'PE' => 'B21'); // From List17, ContributorRole types.
+			$userGroupOnixMap = array('default.groups.name.author' => 'A01', 'default.groups.name.volumeEditor' => 'B01', 'default.groups.name.chapterAuthor' => 'A01', 'default.groups.name.translator' => 'B06', 'default.groups.name.editor' => 'B21'); // From List17, ContributorRole types.
 
-			$role = array_key_exists($userGroup->getLocalizedAbbrev(), $userGroupOnixMap) ? $userGroupOnixMap[$userGroup->getLocalizedAbbrev()] : 'Z99'; // Z99 - unknown contributor type.
+			$nameKey = $userGroup->getData('nameLocaleKey');
+			$role = array_key_exists($nameKey, $userGroupOnixMap) ? $userGroupOnixMap[$nameKey] : 'Z99'; // Z99 - unknown contributor type.
 
 			$contributorNode->appendChild($this->_buildTextNode($doc, 'ContributorRole', $role));
 			$contributorNode->appendChild($this->_buildTextNode($doc, 'PersonName', $author->getFullName(false)));
@@ -356,7 +364,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		}
 
 		if (sizeof($authors) == 0) { // this will probably never happen, but include the possibility.
-			$descDetailNode->appendChild($this->_buildTextNode($doc, 'NoContributor', '')); // empty state of fact.
+			$descDetailNode->appendChild($doc->createElementNS($deployment->getNamespace(), 'NoContributor')); // empty state of fact.
 		}
 
 		/* --- Add Language elements --- */
@@ -402,28 +410,29 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			unset($extentNode);
 		}
 
-
 		/* --- Add Subject elements --- */
 
-		$subjectNode = $doc->createElementNS($deployment->getNamespace(), 'Subject');
-		$mainSubjectNode = $doc->createElementNS($deployment->getNamespace(), 'MainSubject'); // Always empty as per 3.0 spec.
-		$subjectNode->appendChild($mainSubjectNode);
-		$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeIdentifier', '12')); // 12 is BIC subject category code list.
-		$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeVersion', '2')); // Version 2 of ^^
+		if ($publication->getData('subjects')) {
+			$subjectNode = $doc->createElementNS($deployment->getNamespace(), 'Subject');
+			$mainSubjectNode = $doc->createElementNS($deployment->getNamespace(), 'MainSubject'); // Always empty as per 3.0 spec.
 
-		$submissionSubjectDao = DAORegistry::getDAO('SubmissionSubjectDAO');
-		$allSubjects = $submissionSubjectDao->getSubjects($publication->getId(),  array_keys(AppLocale::getSupportedFormLocales()));
-		$uniqueSubjects = array();
-		foreach ($allSubjects as $locale => $subjects) {
-			$uniqueSubjects = array_merge($uniqueSubjects, $subjects);
+			$subjectNode->appendChild($mainSubjectNode);
+			$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeIdentifier', '12')); // 12 is BIC subject category code list.
+			$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeVersion', '2')); // Version 2 of ^^
+
+			$allSubjects = ($publication->getData('subjects')[$publication->getData('locale')]);
+			$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectCode', trim(join(', ', $allSubjects))));
+			$descDetailNode->appendChild($subjectNode);
 		}
 
-		if (sizeof($uniqueSubjects) > 0) {
-			$subjectNode->appendChild($this->_buildTextNode($doc, 'SubjectCode', trim(join(', ', $uniqueSubjects))));
+		if ($publication->getData('keywords')) {
+			$allKeywords = ($publication->getData('keywords')[$publication->getData('locale')]);
+			$keywordNode = $doc->createElementNS($deployment->getNamespace(), 'Subject');
+			$keywordNode->appendChild($this->_buildTextNode($doc, 'SubjectSchemeIdentifier', '20')); // Keywords
+			$keywordNode->appendChild($this->_buildTextNode($doc, 'SubjectHeadingText', trim(join(', ', $allKeywords))));
+			$descDetailNode->appendChild($keywordNode);
 		}
 
-		$descDetailNode->appendChild($subjectNode);
-
 		/* --- Add Audience elements --- */
 
 		if ($submission->getData('audience')) {
@@ -477,6 +486,17 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		$textContentNode->appendChild($this->_buildTextNode($doc, 'ContentAudience', '00')); // Any audience
 		$textContentNode->appendChild($this->_buildTextNode($doc, 'Text', $abstract)); // Any audience
 
+		$supportingResourceNode = $doc->createElementNS($deployment->getNamespace(), 'SupportingResource');
+		$collateralDetailNode->appendChild($supportingResourceNode);
+		$supportingResourceNode->appendChild($this->_buildTextNode($doc, 'ResourceContentType', '01')); // Front cover
+		$supportingResourceNode->appendChild($this->_buildTextNode($doc, 'ContentAudience', '00')); // Any audience
+		$supportingResourceNode->appendChild($this->_buildTextNode($doc, 'ResourceMode', '03')); // A still image
+
+		$resourceVersionNode = $doc->createElementNS($deployment->getNamespace(), 'ResourceVersion');
+		$supportingResourceNode->appendChild($resourceVersionNode);
+		$resourceVersionNode->appendChild($this->_buildTextNode($doc, 'ResourceForm', '01')); // Linkable resource
+		$resourceVersionNode->appendChild($this->_buildTextNode($doc, 'ResourceLink', $publication->getLocalizedCoverImageUrl($context->getId(), $publication->getData('locale'))));
+
 		/* --- Publishing Detail --- */
 
 		$publishingDetailNode = $doc->createElementNS($deployment->getNamespace(), 'PublishingDetail');
@@ -504,6 +524,19 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		$websiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteRole', '18')); // 18 -> Publisher's B2C website
 		$websiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteLink', $request->url($context->getPath())));
 
+		$websiteNode = $doc->createElementNS($deployment->getNamespace(), 'Website');
+		$publisherNode->appendChild($websiteNode);
+
+		$websiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteRole', '29')); // 29 -> Web page for full content
+
+		$submissionBestId = $publication->getData('submissionId');
+
+		if ($publication->getData('urlPath') != '') {
+			$submissionBestId = $publication->getData('urlPath');
+		}
+
+		$websiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteLink', $request->url($context->getPath(), 'catalog', 'book', $submissionBestId)));
+
 		/* --- Publishing Dates --- */
 
 		$publicationDates = $publicationFormat->getPublicationDates();
@@ -528,33 +561,41 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 		$allSalesRights = $publicationFormat->getSalesRights();
 		$salesRightsROW = null;
 		while ($salesRights = $allSalesRights->next()) {
-			if (!$salesRights->getROWSetting()) {
 
-				$salesRightsNode = $doc->createElementNS($deployment->getNamespace(), 'SalesRights');
-				$publishingDetailNode->appendChild($salesRightsNode);
-				$salesRightsNode->appendChild($this->_buildTextNode($doc, 'SalesRightsType', $salesRights->getType()));
+			$salesRightsNode = $doc->createElementNS($deployment->getNamespace(), 'SalesRights');
+			$publishingDetailNode->appendChild($salesRightsNode);
+			$salesRightsNode->appendChild($this->_buildTextNode($doc, 'SalesRightsType', $salesRights->getType()));
 
-				// now do territories and countries.
-				$territoryNode = $doc->createElementNS($deployment->getNamespace(), 'Territory');
-				$salesRightsNode->appendChild($territoryNode);
+			// now do territories and countries.
+			$territoryNode = $doc->createElementNS($deployment->getNamespace(), 'Territory');
+			$salesRightsNode->appendChild($territoryNode);
 
-				if (sizeof($salesRights->getRegionsIncluded()) > 0 && sizeof($salesRights->getCountriesExcluded()) > 0) {
-					$territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsIncluded', trim(join(' ', $salesRights->getRegionsIncluded()))));
-					$territoryNode->appendChild($this->_buildTextNode($doc, 'CountriesExcluded', trim(join(' ', $salesRights->getCountriesExcluded()))));
-				} else if (sizeof($salesRights->getCountriesIncluded()) > 0) {
-					$territoryNode->appendChild($this->_buildTextNode($doc, 'CountriesIncluded', trim(join(' ', $salesRights->getCountriesIncluded()))));
-				}
+			$salesCountriesIncluded = sizeof($salesRights->getCountriesIncluded()) > 0;
+			$salesRegionsIncluded = sizeof($salesRights->getRegionsIncluded()) > 0;
+			$salesCountriesExcluded = sizeof($salesRights->getCountriesExcluded()) > 0;
+			$salesRegionsExcluded = sizeof($salesRights->getRegionsExcluded()) > 0;
 
-				if (sizeof($salesRights->getRegionsExcluded()) > 0) {
+			if ($salesRights->getROWSetting()) {
+				$territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsIncluded', 'WORLD'));
+				$salesRightsROW = $salesRights;
+			} else if ($salesCountriesIncluded) {
+				$territoryNode->appendChild($this->_buildTextNode($doc, 'CountriesIncluded', trim(join(' ', $salesRights->getCountriesIncluded()))));
+				if (!in_array('WORLD', $salesRights->getRegionsIncluded())) {
+					if ($salesRegionsIncluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsIncluded', trim(join(' ', $salesRights->getRegionsIncluded()))));
+					if ($salesRegionsExcluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsExcluded', trim(join(' ', $salesRights->getRegionsExcluded()))));
+				} else if ($salesRegionsExcluded) {
 					$territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsExcluded', trim(join(' ', $salesRights->getRegionsExcluded()))));
 				}
-
-				unset($territoryNode);
-				unset($salesRightsNode);
-
-			} else { // found the SalesRights object that is assigned 'rest of world'.
-				$salesRightsROW = $salesRights; // stash this for later since it always goes last.
+			} else if ($salesRegionsIncluded) {
+				$territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsIncluded', trim(join(' ', $salesRights->getRegionsIncluded()))));
+				if (in_array('WORLD', $salesRights->getRegionsIncluded())) {
+					if ($salesCountriesExcluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'CountriesExcluded', trim(join(' ', $salesRights->getCountriesExcluded()))));
+					if ($salesRegionsExcluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsExcluded', trim(join(' ', $salesRights->getRegionsExcluded()))));
+				}
 			}
+
+			unset($territoryNode);
+			unset($salesRightsNode);
 			unset($salesRights);
 		}
 		if ($salesRightsROW != null) {
@@ -576,20 +617,25 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$territoryNode = $doc->createElementNS($deployment->getNamespace(), 'Territory');
 			$marketNode->appendChild($territoryNode);
 
-			if (sizeof($market->getCountriesIncluded()) > 0) {
+			$marketCountriesIncluded = sizeof($market->getCountriesIncluded()) > 0;
+			$marketRegionsIncluded = sizeof($market->getRegionsIncluded()) > 0;
+			$marketCountriesExcluded = sizeof($market->getCountriesExcluded()) > 0;
+			$marketRegionsExcluded = sizeof($market->getRegionsExcluded()) > 0;
+
+			if ($marketCountriesIncluded) {
 				$territoryNode->appendChild($this->_buildTextNode($doc, 'CountriesIncluded', trim(join(' ', $market->getCountriesIncluded()))));
-			}
-
-			if (sizeof($market->getRegionsIncluded()) > 0) {
+				if (!in_array('WORLD', $market->getRegionsIncluded())) {
+					if ($marketRegionsIncluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsIncluded', trim(join(' ', $market->getRegionsIncluded()))));
+					if ($marketRegionsExcluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsExcluded', trim(join(' ', $market->getRegionsExcluded()))));
+				} else if ($marketRegionsExcluded) {
+					$territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsExcluded', trim(join(' ', $market->getRegionsExcluded()))));
+				}
+			} else if ($marketRegionsIncluded) {
 				$territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsIncluded', trim(join(' ', $market->getRegionsIncluded()))));
-			}
-
-			if (sizeof($market->getCountriesExcluded()) > 0) {
-				$territoryNode->appendChild($this->_buildTextNode($doc, 'CountriesExcluded', trim(join(' ', $market->getCountriesExcluded()))));
-			}
-
-			if (sizeof($market->getRegionsExcluded()) > 0) {
-				$territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsExcluded', trim(join(' ', $market->getRegionsExcluded()))));
+				if (in_array('WORLD', $market->getRegionsIncluded())) {
+					if ($marketCountriesExcluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'CountriesExcluded', trim(join(' ', $market->getCountriesExcluded()))));
+					if ($marketRegionsExcluded) $territoryNode->appendChild($this->_buildTextNode($doc, 'RegionsExcluded', trim(join(' ', $market->getRegionsExcluded()))));
+				}
 			}
 
 			unset($marketNode);
@@ -661,6 +707,12 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 					unset($supplierWebsiteNode);
 				}
+
+				$supplierWebsiteNode = $doc->createElementNS($deployment->getNamespace(), 'Website');
+				$supplierNode->appendChild($supplierWebsiteNode);
+
+				$supplierWebsiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteRole', '29')); // 29 -> Web page for full content
+				$supplierWebsiteNode->appendChild($this->_buildTextNode($doc, 'WebsiteLink', $request->url($context->getPath(), 'catalog', 'book', $submissionBestId)));
 				unset($supplierNode);
 				unset($supplierWebsiteNode);
 
@@ -701,8 +753,12 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 			$priceNode = $doc->createElementNS($deployment->getNamespace(), 'Price');
 			$supplyDetailNode->appendChild($priceNode);
 
+			$excludeTaxNode = false;
+
 			if ($market->getPriceTypeCode() != '') {
  				$priceNode->appendChild($this->_buildTextNode($doc, 'PriceType', $market->getPriceTypeCode()));
+				$priceTypeTaxEx = ['02', '04', '07', '09', '12', '14', '17', '22', '24', '27', '34', '42']; // Price type codes that include tax
+				if (in_array($market->getPriceTypeCode(), $priceTypeTaxEx)) $excludeTaxNode = true;
 			}
 
 			if ($market->getDiscount() != '') {
@@ -714,7 +770,7 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 
 			$priceNode->appendChild($this->_buildTextNode($doc, 'PriceAmount', $market->getPrice()));
 
-			if ($market->getTaxTypeCode() != '' || $market->getTaxRateCode() != '') {
+			if (!$excludeTaxNode && ($market->getTaxTypeCode() != '' || $market->getTaxRateCode() != '')) {
 				$taxNode = $doc->createElementNS($deployment->getNamespace(), 'Tax');
 				$priceNode->appendChild($taxNode);
 
@@ -723,7 +779,12 @@ class MonographONIX30XmlFilter extends NativeExportFilter {
 				}
 				if ($market->getTaxRateCode()) {
 					$taxNode->appendChild($this->_buildTextNode($doc, 'TaxRateCode', $market->getTaxRateCode()));
+					if ($market->getTaxRateCode() == 'Z') {
+						$taxNode->appendChild($this->_buildTextNode($doc, 'TaxRatePercent', '0')); // Zero-rated tax rate type
+					}
 				}
+
+				$taxNode->appendChild($this->_buildTextNode($doc, 'TaxableAmount', $market->getPrice())); // Taxable amount defaults to full price
 				unset($taxNode);
 			}
 
