@@ -3,8 +3,8 @@
 /**
  * @file plugins/importexport/native/filter/NativeXmlPublicationFormatFilter.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class NativeXmlPublicationFormatFilter
@@ -71,7 +71,7 @@ class NativeXmlPublicationFormatFilter extends NativeXmlRepresentationFilter {
 		if ($node->getAttribute('available') == 'true') $representation->setIsAvailable(true);
 		if ($node->getAttribute('physical_format') == 'true') $representation->setPhysicalFormat(true);
 		if ($node->getAttribute('entry_key')) $representation->setEntryKey($node->getAttribute('entry_key'));
-		
+
 
 		$representationDao = Application::getRepresentationDAO();
 		$representationDao->insertObject($representation);
@@ -98,14 +98,13 @@ class NativeXmlPublicationFormatFilter extends NativeXmlRepresentationFilter {
 	 */
 	function _processFileRef($node, $deployment, &$representation) {
 		$fileId = $node->getAttribute('id');
-		$revisionId = $node->getAttribute('revision');
-		$DBId = $deployment->getFileDBId($fileId, $revisionId);
+		$DBId = $deployment->getSubmissionFileDBId($fileId);
 		if ($DBId) {
 			// Update the submission file.
 			$submissionFileDao = DAORegistry::getDAO('SubmissionFileDAO'); /* @var $submissionFileDao SubmissionFileDAO */
-			$submissionFile = $submissionFileDao->getRevision($DBId, $revisionId);
+			$submissionFile = Services::get('submissionFile')->get($DBId);
 			$submissionFile->setAssocType(ASSOC_TYPE_REPRESENTATION);
-			$submissionFile->setAssocId($representation->getId());
+			$submissionFile->setData('assocId', $representation->getId());
 			$submissionFileDao->updateObject($submissionFile);
 		}
 	}
@@ -113,6 +112,7 @@ class NativeXmlPublicationFormatFilter extends NativeXmlRepresentationFilter {
 	/**
 	 * Process the Product node found inside the publication_format node.  There may be many of these.
 	 * @param $node DOMElement
+	 * @param $deployment PKPImportExportDeployment
 	 * @param $representation PublicationFormat
 	 */
 	function _processProductNode($node, $deployment, &$representation) {
@@ -120,6 +120,8 @@ class NativeXmlPublicationFormatFilter extends NativeXmlRepresentationFilter {
 		$request = Application::get()->getRequest();
 		$onixDeployment = new Onix30ExportDeployment($request->getContext(), $request->getUser());
 
+		$submission = $deployment->getSubmission();
+
 		$representation->setProductCompositionCode($this->_extractTextFromNode($node, $onixDeployment, 'ProductComposition'));
 		$representation->setEntryKey($this->_extractTextFromNode($node, $onixDeployment, 'ProductForm'));
 		$representation->setProductFormDetailCode($this->_extractTextFromNode($node, $onixDeployment, 'ProductFormDetail'));
@@ -129,11 +131,11 @@ class NativeXmlPublicationFormatFilter extends NativeXmlRepresentationFilter {
 		$this->_extractMeasureContent($node, $onixDeployment, $representation);
 		$this->_extractExtentContent($node, $onixDeployment, $representation);
 
-		$submission = Services::get('submission')->get($representation->getSubmissionId());
 		if ($submission) {
-			$submission->setAudience($this->_extractTextFromNode($node, $onixDeployment, 'AudienceCodeType'));
-			$submission->setAudienceRangeQualifier($this->_extractTextFromNode($node, $onixDeployment, 'AudienceRangeQualifier'));
-			$this->_extractAudienceRangeContent($node, $onixDeployment, $representation);
+			$submission->setData('audience', $this->_extractTextFromNode($node, $onixDeployment, 'AudienceCodeType'));
+			$submission->setData('audienceRangeQualifier', $this->_extractTextFromNode($node, $onixDeployment, 'AudienceRangeQualifier'));
+			$this->_extractAudienceRangeContent($node, $onixDeployment, $submission);
+
 			DAORegistry::getDAO('SubmissionDAO')->updateObject($submission);
 		}
 
@@ -402,9 +404,9 @@ class NativeXmlPublicationFormatFilter extends NativeXmlRepresentationFilter {
 	 * a submission defines a specific range, or a to/from pair.
 	 * @param $node DOMElement
 	 * @param $onixDeployment Onix30ExportDeployment
-	 * @param PublicationFormat $representation
+	 * @param Submission $submission
 	 */
-	function _extractAudienceRangeContent($node, $onixDeployment, &$representation) {
+	function _extractAudienceRangeContent($node, $onixDeployment, &$submission) {
 		$nodeList = $node->getElementsByTagNameNS($onixDeployment->getNamespace(), 'AudienceRange');
 		for ($i = 0 ; $i < $nodeList->length ; $i++) {
 			$n = $nodeList->item($i);
@@ -414,13 +416,13 @@ class NativeXmlPublicationFormatFilter extends NativeXmlRepresentationFilter {
 				case 'AudienceRangeValue':
 					switch ($audienceRangePrecision) {
 						case '01':
-							$representation->setAudienceRangeExact($o->textContent);
+							$submission->setData('audienceRangeExact', $o->textContent);
 							break;
 						case '03':
-							$representation->setAudienceRangeTo($o->textContent);
+							$submission->setData('audienceRangeTo', $o->textContent);
 							break;
 						case '04':
-							$representation->setAudienceRangeFrom($o->textContent);
+							$submission->setData('audienceRangeFrom', $o->textContent);
 							break;
 					}
 					break;
